SetPermissionStatusEvent class

Set whether the app may read location (wire from juice_permissions).

Inheritance

Constructors

SetPermissionStatusEvent(bool granted)

Properties

granted bool
final
groupsToRebuild Set<String>?
The set of widget rebuild groups this event should trigger.
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() Future<void>
Called when the event is disposed.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited