GeoPosition class
A vendor-agnostic position fix.
Constructors
Properties
- accuracy → double
-
Estimated accuracy in metres.
final
- altitude → double
-
Altitude in metres (0 if unavailable).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- heading → double
-
Heading in degrees (0 if unavailable).
final
- latitude → double
-
final
- longitude → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- speed → double
-
Speed in m/s (0 if unavailable).
final
- timestamp → DateTime
-
When the fix was taken.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited